pub fn parse_args(argv: &[String]) -> Result<Args, String>Expand description
Parse argv, or return the message a parse failure would print.
Errors
Returns the failure text when a token is not a valid option, an abbreviation is ambiguous, or an option that takes a value was not given one.